##  FAQs
### How can I trace whether emails were successfully sent?
To learn how to trace whether your emails were successfully delivered, visit the [Microsoft documentation![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearn.microsoft.com%2Fen-us%2Fexchange%2Fmonitoring%2Ftrace-an-email-message%2Ftrace-an-email-message "https://learn.microsoft.com/en-us/exchange/monitoring/trace-an-email-message/trace-an-email-message").
### Can I use shared and regular mailboxes to send emails?
Yes, you can use both shared mailboxes and mailboxes assigned to individual users.
### How to find my Microsoft Entra Tenant ID?
To learn how to find the ID of your Microsoft Entra ID tenant, visit the [Microsoft documentation![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearn.microsoft.com%2Fen-us%2Fentra%2Ffundamentals%2Fhow-to-find-tenant "https://learn.microsoft.com/en-us/entra/fundamentals/how-to-find-tenant").
